@@ -1,3 +1,5 @@
+'''Functions for estimating clear-sky ambient temperature.'''
+
 import h5py
 from numpy import arange
 from datetime import timedelta
@@ -6,31 +8,42 @@ import pkg_resources
 import numpy as np
 import warnings
 
-def get_clearsky_tamb(times, latitude, longitude, window_size=40, gauss_std=20):
+
+def get_clearsky_tamb(times, latitude, longitude, window_size=40,
+                      gauss_std=20):
     '''
-    Description
-    -----------
-    Estimates the ambient temperature at latitude and longitude for the given times
+    Estimates the ambient temperature at latitude and longitude for the given
+    times using a Gaussian rolling window.
 
     Parameters
     ----------
-    times:       DateTimeIndex in local time
-    latitude:    float degrees
-    longitude:   float degrees
+    times : pandas.DatetimeIndex
+        A pandas DatetimeIndex, localized to local time
+    latitude : float
+        Coordinates in decimal degrees.
+    longitude : float
+        Coordinates in decimal degrees. Positive is east of the prime meridian.
+    window_size : int, default 40
+        The window size in days to use when calculating rolling averages.
+    gauss_std : int, default 20
+        The standard deviation in days to use for the Gaussian rolling window.
 
     Returns
     -------
-    pandas Series of clear sky ambient temperature
+    pandas.Series
+        clear sky ambient temperature
 
-    Reference
-    ---------
+    Notes
+    -----
     Uses data from images created by Jesse Allen, NASA's Earth Observatory
     using data courtesy of the MODIS Land Group.
-    https://neo.sci.gsfc.nasa.gov/view.php?datasetId=MOD_LSTD_CLIM_M
-    https://neo.sci.gsfc.nasa.gov/view.php?datasetId=MOD_LSTN_CLIM_M
+
+    * https://neo.sci.gsfc.nasa.gov/view.php?datasetId=MOD_LSTD_CLIM_M
+    * https://neo.sci.gsfc.nasa.gov/view.php?datasetId=MOD_LSTN_CLIM_M
     '''
 
-    filepath = pkg_resources.resource_filename('rdtools', 'data/temperature.hdf5')
+    filepath = pkg_resources.resource_filename('rdtools',
+                                               'data/temperature.hdf5')
 
     buffer = timedelta(days=window_size)
 
@@ -38,11 +51,13 @@ def get_clearsky_tamb(times, latitude, longitude, window_size=40, gauss_std=20):
         freq_actual = pd.infer_freq(times)
         if freq_actual is None:
             freq_actual = pd.infer_freq(times[:10])
-            warnings.warn("Input 'times' has no frequency attribute. Inferring frequency from first 10 timestamps.")
+            warnings.warn("Input 'times' has no frequency attribute. "
+                          "Inferring frequency from first 10 timestamps.")
     else:
         freq_actual = times.freq
 
-    dt_daily = pd.date_range(times.date[0] - buffer, times.date[-1] + buffer, freq='D', tz=times.tz)
+    dt_daily = pd.date_range(times.date[0] - buffer, times.date[-1] + buffer,
+                             freq='D', tz=times.tz)
 
     f = h5py.File(filepath, "r")
 
@@ -70,11 +85,6 @@ def get_clearsky_tamb(times, latitude, longitude, window_size=40, gauss_std=20):
         day = _get_pixel_value(a, lon_index, lat_index, k, radius)
         night = _get_pixel_value(b, lon_index, lat_index, k, radius)
 
-        if pd.isnull(day):
-            day = a[:, lat_index, k]
-        if pd.isnull(night):
-            night = a[:, lat_index, k]
-
         ave_day.append(day)
         ave_night.append(night)
 
@@ -82,7 +92,8 @@ def get_clearsky_tamb(times, latitude, longitude, window_size=40, gauss_std=20):
         df.loc[df['month'] == i + 1, 'day'] = ave_day[i]
         df.loc[df['month'] == i + 1, 'night'] = ave_night[i]
 
-    df = df.rolling(window=window_size, win_type='gaussian', min_periods=1, center=True).mean(std=gauss_std)
+    df = df.rolling(window=window_size, win_type='gaussian', min_periods=1,
+                    center=True).mean(std=gauss_std)
 
     df = df.resample(freq_actual).interpolate(method='linear')
     df['month'] = df.index.month
@@ -97,8 +108,14 @@ def get_clearsky_tamb(times, latitude, longitude, window_size=40, gauss_std=20):
     df['solar_noon_offset'] = solar_noon_offset(np.array(utc_offsets))
 
     df['hour_of_day'] = df.index.hour + df.index.minute / 60.0
-    df['Clear Sky Temperature (C)'] = _get_temperature(df['hour_of_day'].values, df['night'].values,\
-                                                       df['day'].values, df['solar_noon_offset'].values)
+    df['Clear Sky Temperature (C)'] = _get_temperature(
+            df['hour_of_day'].values,
+            df['night'].values,
+            df['day'].values,
+            df['solar_noon_offset'].values)
+    if df['Clear Sky Temperature (C)'].isna().any():
+        warnings.warn("Clear Sky Temperature includes NaNs, "
+                      "possibly invalid Lat/Lon coordinates.", UserWarning)
     return df['Clear Sky Temperature (C)']
 
 
@@ -120,7 +137,7 @@ def _get_pixel_value(data, i, j, k, radius):
     if len(list) == 0:
         return np.nan
 
-    return pd.Series(list).median()
+    return float(pd.Series(list).median())
 
 
 def _get_temperature(hour_of_day, night_temp, day_temp, solar_noon_offset):
